==> zio-aws-grafana_2.13-5.17.123.2-sources.jar: zio/aws/grafana/model/CreateWorkspaceRequest.scala <==
package zio.aws.grafana.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.grafana.model.primitives.{
  IamRoleArn,
  OrganizationRoleName,
  OrganizationalUnit,
  StackSetName,
  WorkspaceName,
  Description,
  ClientToken
}
import scala.jdk.CollectionConverters._
final case class CreateWorkspaceRequest(
    accountAccessType: zio.aws.grafana.model.AccountAccessType,
    authenticationProviders: Iterable[
      zio.aws.grafana.model.AuthenticationProviderTypes
    ],
    clientToken: Option[ClientToken] = None,
    organizationRoleName: Option[OrganizationRoleName] = None,
    permissionType: zio.aws.grafana.model.PermissionType,
    stackSetName: Option[StackSetName] = None,
    workspaceDataSources: Option[
      Iterable[zio.aws.grafana.model.DataSourceType]
    ] = None,
    workspaceDescription: Option[Description] = None,
    workspaceName: Option[WorkspaceName] = None,
    workspaceNotificationDestinations: Option[
      Iterable[zio.aws.grafana.model.NotificationDestinationType]
    ] = None,
    workspaceOrganizationalUnits: Option[Iterable[OrganizationalUnit]] = None,
    workspaceRoleArn: Option[IamRoleArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest = {
    import CreateWorkspaceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
      .builder()
      .accountAccessType(accountAccessType.unwrap)
      .authenticationProvidersWithStrings(authenticationProviders.map { item =>
        item.unwrap.toString
      }.asJavaCollection)
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .optionallyWith(
        organizationRoleName.map(value =>
          OrganizationRoleName.unwrap(value): java.lang.String
        )
      )(_.organizationRoleName)
      .permissionType(permissionType.unwrap)
      .optionallyWith(
        stackSetName.map(value => StackSetName.unwrap(value): java.lang.String)
      )(_.stackSetName)
      .optionallyWith(
        workspaceDataSources.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.workspaceDataSourcesWithStrings)
      .optionallyWith(
        workspaceDescription.map(value =>
          Description.unwrap(value): java.lang.String
        )
      )(_.workspaceDescription)
      .optionallyWith(
        workspaceName.map(value =>
          WorkspaceName.unwrap(value): java.lang.String
        )
      )(_.workspaceName)
      .optionallyWith(
        workspaceNotificationDestinations.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.workspaceNotificationDestinationsWithStrings)
      .optionallyWith(
        workspaceOrganizationalUnits.map(value =>
          value.map { item =>
            OrganizationalUnit.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.workspaceOrganizationalUnits)
      .optionallyWith(
        workspaceRoleArn.map(value =>
          IamRoleArn.unwrap(value): java.lang.String
        )
      )(_.workspaceRoleArn)
      .build()
  }
  def asReadOnly: zio.aws.grafana.model.CreateWorkspaceRequest.ReadOnly =
    zio.aws.grafana.model.CreateWorkspaceRequest.wrap(buildAwsValue())
}
object CreateWorkspaceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.grafana.model.CreateWorkspaceRequest =
      zio.aws.grafana.model.CreateWorkspaceRequest(
        accountAccessType,
        authenticationProviders,
        clientToken.map(value => value),
        organizationRoleName.map(value => value),
        permissionType,
        stackSetName.map(value => value),
        workspaceDataSources.map(value => value),
        workspaceDescription.map(value => value),
        workspaceName.map(value => value),
        workspaceNotificationDestinations.map(value => value),
        workspaceOrganizationalUnits.map(value => value),
        workspaceRoleArn.map(value => value)
      )
    def accountAccessType: zio.aws.grafana.model.AccountAccessType
    def authenticationProviders
        : List[zio.aws.grafana.model.AuthenticationProviderTypes]
    def clientToken: Option[ClientToken]
    def organizationRoleName: Option[OrganizationRoleName]
    def permissionType: zio.aws.grafana.model.PermissionType
    def stackSetName: Option[StackSetName]
    def workspaceDataSources: Option[List[zio.aws.grafana.model.DataSourceType]]
    def workspaceDescription: Option[Description]
    def workspaceName: Option[WorkspaceName]
    def workspaceNotificationDestinations
        : Option[List[zio.aws.grafana.model.NotificationDestinationType]]
    def workspaceOrganizationalUnits: Option[List[OrganizationalUnit]]
    def workspaceRoleArn: Option[IamRoleArn]
    def getAccountAccessType
        : ZIO[Any, Nothing, zio.aws.grafana.model.AccountAccessType] =
      ZIO.succeed(accountAccessType)
    def getAuthenticationProviders: ZIO[Any, Nothing, List[
      zio.aws.grafana.model.AuthenticationProviderTypes
    ]] = ZIO.succeed(authenticationProviders)
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getOrganizationRoleName: ZIO[Any, AwsError, OrganizationRoleName] =
      AwsError.unwrapOptionField("organizationRoleName", organizationRoleName)
    def getPermissionType
        : ZIO[Any, Nothing, zio.aws.grafana.model.PermissionType] =
      ZIO.succeed(permissionType)
    def getStackSetName: ZIO[Any, AwsError, StackSetName] =
      AwsError.unwrapOptionField("stackSetName", stackSetName)
    def getWorkspaceDataSources
        : ZIO[Any, AwsError, List[zio.aws.grafana.model.DataSourceType]] =
      AwsError.unwrapOptionField("workspaceDataSources", workspaceDataSources)
    def getWorkspaceDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("workspaceDescription", workspaceDescription)
    def getWorkspaceName: ZIO[Any, AwsError, WorkspaceName] =
      AwsError.unwrapOptionField("workspaceName", workspaceName)
    def getWorkspaceNotificationDestinations: ZIO[Any, AwsError, List[
      zio.aws.grafana.model.NotificationDestinationType
    ]] = AwsError.unwrapOptionField(
      "workspaceNotificationDestinations",
      workspaceNotificationDestinations
    )
    def getWorkspaceOrganizationalUnits
        : ZIO[Any, AwsError, List[OrganizationalUnit]] =
      AwsError.unwrapOptionField(
        "workspaceOrganizationalUnits",
        workspaceOrganizationalUnits
      )
    def getWorkspaceRoleArn: ZIO[Any, AwsError, IamRoleArn] =
      AwsError.unwrapOptionField("workspaceRoleArn", workspaceRoleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
  ) extends zio.aws.grafana.model.CreateWorkspaceRequest.ReadOnly {
    override val accountAccessType: zio.aws.grafana.model.AccountAccessType =
      zio.aws.grafana.model.AccountAccessType.wrap(impl.accountAccessType())
    override val authenticationProviders
        : List[zio.aws.grafana.model.AuthenticationProviderTypes] = impl
      .authenticationProviders()
      .asScala
      .map { item =>
        zio.aws.grafana.model.AuthenticationProviderTypes.wrap(item)
      }
      .toList
    override val clientToken: Option[ClientToken] = scala
      .Option(impl.clientToken())
      .map(value => zio.aws.grafana.model.primitives.ClientToken(value))
    override val organizationRoleName: Option[OrganizationRoleName] = scala
      .Option(impl.organizationRoleName())
      .map(value =>
        zio.aws.grafana.model.primitives.OrganizationRoleName(value)
      )
    override val permissionType: zio.aws.grafana.model.PermissionType =
      zio.aws.grafana.model.PermissionType.wrap(impl.permissionType())
    override val stackSetName: Option[StackSetName] = scala
      .Option(impl.stackSetName())
      .map(value => zio.aws.grafana.model.primitives.StackSetName(value))
    override val workspaceDataSources
        : Option[List[zio.aws.grafana.model.DataSourceType]] = scala
      .Option(impl.workspaceDataSources())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.grafana.model.DataSourceType.wrap(item)
        }.toList
      )
    override val workspaceDescription: Option[Description] = scala
      .Option(impl.workspaceDescription())
      .map(value => zio.aws.grafana.model.primitives.Description(value))
    override val workspaceName: Option[WorkspaceName] = scala
      .Option(impl.workspaceName())
      .map(value => zio.aws.grafana.model.primitives.WorkspaceName(value))
    override val workspaceNotificationDestinations
        : Option[List[zio.aws.grafana.model.NotificationDestinationType]] =
      scala
        .Option(impl.workspaceNotificationDestinations())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.grafana.model.NotificationDestinationType.wrap(item)
          }.toList
        )
    override val workspaceOrganizationalUnits
        : Option[List[OrganizationalUnit]] = scala
      .Option(impl.workspaceOrganizationalUnits())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.grafana.model.primitives.OrganizationalUnit(item)
        }.toList
      )
    override val workspaceRoleArn: Option[IamRoleArn] = scala
      .Option(impl.workspaceRoleArn())
      .map(value => zio.aws.grafana.model.primitives.IamRoleArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
  ): zio.aws.grafana.model.CreateWorkspaceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-grafana_2.13-5.17.188.1-sources.jar: zio/aws/grafana/model/CreateWorkspaceRequest.scala <==
package zio.aws.grafana.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.grafana.model.primitives.{
  IamRoleArn,
  OrganizationRoleName,
  OrganizationalUnit,
  StackSetName,
  TagValue,
  WorkspaceName,
  Description,
  ClientToken,
  TagKey
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateWorkspaceRequest(
    accountAccessType: zio.aws.grafana.model.AccountAccessType,
    authenticationProviders: Iterable[
      zio.aws.grafana.model.AuthenticationProviderTypes
    ],
    clientToken: Optional[ClientToken] = Optional.Absent,
    organizationRoleName: Optional[OrganizationRoleName] = Optional.Absent,
    permissionType: zio.aws.grafana.model.PermissionType,
    stackSetName: Optional[StackSetName] = Optional.Absent,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent,
    workspaceDataSources: Optional[
      Iterable[zio.aws.grafana.model.DataSourceType]
    ] = Optional.Absent,
    workspaceDescription: Optional[Description] = Optional.Absent,
    workspaceName: Optional[WorkspaceName] = Optional.Absent,
    workspaceNotificationDestinations: Optional[
      Iterable[zio.aws.grafana.model.NotificationDestinationType]
    ] = Optional.Absent,
    workspaceOrganizationalUnits: Optional[Iterable[OrganizationalUnit]] =
      Optional.Absent,
    workspaceRoleArn: Optional[IamRoleArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest = {
    import CreateWorkspaceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
      .builder()
      .accountAccessType(accountAccessType.unwrap)
      .authenticationProvidersWithStrings(authenticationProviders.map { item =>
        item.unwrap.toString
      }.asJavaCollection)
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .optionallyWith(
        organizationRoleName.map(value =>
          OrganizationRoleName.unwrap(value): java.lang.String
        )
      )(_.organizationRoleName)
      .permissionType(permissionType.unwrap)
      .optionallyWith(
        stackSetName.map(value => StackSetName.unwrap(value): java.lang.String)
      )(_.stackSetName)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(
        workspaceDataSources.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.workspaceDataSourcesWithStrings)
      .optionallyWith(
        workspaceDescription.map(value =>
          Description.unwrap(value): java.lang.String
        )
      )(_.workspaceDescription)
      .optionallyWith(
        workspaceName.map(value =>
          WorkspaceName.unwrap(value): java.lang.String
        )
      )(_.workspaceName)
      .optionallyWith(
        workspaceNotificationDestinations.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.workspaceNotificationDestinationsWithStrings)
      .optionallyWith(
        workspaceOrganizationalUnits.map(value =>
          value.map { item =>
            OrganizationalUnit.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.workspaceOrganizationalUnits)
      .optionallyWith(
        workspaceRoleArn.map(value =>
          IamRoleArn.unwrap(value): java.lang.String
        )
      )(_.workspaceRoleArn)
      .build()
  }
  def asReadOnly: zio.aws.grafana.model.CreateWorkspaceRequest.ReadOnly =
    zio.aws.grafana.model.CreateWorkspaceRequest.wrap(buildAwsValue())
}
object CreateWorkspaceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.grafana.model.CreateWorkspaceRequest =
      zio.aws.grafana.model.CreateWorkspaceRequest(
        accountAccessType,
        authenticationProviders,
        clientToken.map(value => value),
        organizationRoleName.map(value => value),
        permissionType,
        stackSetName.map(value => value),
        tags.map(value => value),
        workspaceDataSources.map(value => value),
        workspaceDescription.map(value => value),
        workspaceName.map(value => value),
        workspaceNotificationDestinations.map(value => value),
        workspaceOrganizationalUnits.map(value => value),
        workspaceRoleArn.map(value => value)
      )
    def accountAccessType: zio.aws.grafana.model.AccountAccessType
    def authenticationProviders
        : List[zio.aws.grafana.model.AuthenticationProviderTypes]
    def clientToken: Optional[ClientToken]
    def organizationRoleName: Optional[OrganizationRoleName]
    def permissionType: zio.aws.grafana.model.PermissionType
    def stackSetName: Optional[StackSetName]
    def tags: Optional[Map[TagKey, TagValue]]
    def workspaceDataSources
        : Optional[List[zio.aws.grafana.model.DataSourceType]]
    def workspaceDescription: Optional[Description]
    def workspaceName: Optional[WorkspaceName]
    def workspaceNotificationDestinations
        : Optional[List[zio.aws.grafana.model.NotificationDestinationType]]
    def workspaceOrganizationalUnits: Optional[List[OrganizationalUnit]]
    def workspaceRoleArn: Optional[IamRoleArn]
    def getAccountAccessType
        : ZIO[Any, Nothing, zio.aws.grafana.model.AccountAccessType] =
      ZIO.succeed(accountAccessType)
    def getAuthenticationProviders: ZIO[Any, Nothing, List[
      zio.aws.grafana.model.AuthenticationProviderTypes
    ]] = ZIO.succeed(authenticationProviders)
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getOrganizationRoleName: ZIO[Any, AwsError, OrganizationRoleName] =
      AwsError.unwrapOptionField("organizationRoleName", organizationRoleName)
    def getPermissionType
        : ZIO[Any, Nothing, zio.aws.grafana.model.PermissionType] =
      ZIO.succeed(permissionType)
    def getStackSetName: ZIO[Any, AwsError, StackSetName] =
      AwsError.unwrapOptionField("stackSetName", stackSetName)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
    def getWorkspaceDataSources
        : ZIO[Any, AwsError, List[zio.aws.grafana.model.DataSourceType]] =
      AwsError.unwrapOptionField("workspaceDataSources", workspaceDataSources)
    def getWorkspaceDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("workspaceDescription", workspaceDescription)
    def getWorkspaceName: ZIO[Any, AwsError, WorkspaceName] =
      AwsError.unwrapOptionField("workspaceName", workspaceName)
    def getWorkspaceNotificationDestinations: ZIO[Any, AwsError, List[
      zio.aws.grafana.model.NotificationDestinationType
    ]] = AwsError.unwrapOptionField(
      "workspaceNotificationDestinations",
      workspaceNotificationDestinations
    )
    def getWorkspaceOrganizationalUnits
        : ZIO[Any, AwsError, List[OrganizationalUnit]] =
      AwsError.unwrapOptionField(
        "workspaceOrganizationalUnits",
        workspaceOrganizationalUnits
      )
    def getWorkspaceRoleArn: ZIO[Any, AwsError, IamRoleArn] =
      AwsError.unwrapOptionField("workspaceRoleArn", workspaceRoleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
  ) extends zio.aws.grafana.model.CreateWorkspaceRequest.ReadOnly {
    override val accountAccessType: zio.aws.grafana.model.AccountAccessType =
      zio.aws.grafana.model.AccountAccessType.wrap(impl.accountAccessType())
    override val authenticationProviders
        : List[zio.aws.grafana.model.AuthenticationProviderTypes] = impl
      .authenticationProviders()
      .asScala
      .map { item =>
        zio.aws.grafana.model.AuthenticationProviderTypes.wrap(item)
      }
      .toList
    override val clientToken: Optional[ClientToken] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => zio.aws.grafana.model.primitives.ClientToken(value))
    override val organizationRoleName: Optional[OrganizationRoleName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.organizationRoleName())
        .map(value =>
          zio.aws.grafana.model.primitives.OrganizationRoleName(value)
        )
    override val permissionType: zio.aws.grafana.model.PermissionType =
      zio.aws.grafana.model.PermissionType.wrap(impl.permissionType())
    override val stackSetName: Optional[StackSetName] = zio.aws.core.internal
      .optionalFromNullable(impl.stackSetName())
      .map(value => zio.aws.grafana.model.primitives.StackSetName(value))
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.grafana.model.primitives
              .TagKey(key) -> zio.aws.grafana.model.primitives.TagValue(value)
          })
          .toMap
      )
    override val workspaceDataSources
        : Optional[List[zio.aws.grafana.model.DataSourceType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceDataSources())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.grafana.model.DataSourceType.wrap(item)
          }.toList
        )
    override val workspaceDescription: Optional[Description] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceDescription())
        .map(value => zio.aws.grafana.model.primitives.Description(value))
    override val workspaceName: Optional[WorkspaceName] = zio.aws.core.internal
      .optionalFromNullable(impl.workspaceName())
      .map(value => zio.aws.grafana.model.primitives.WorkspaceName(value))
    override val workspaceNotificationDestinations
        : Optional[List[zio.aws.grafana.model.NotificationDestinationType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceNotificationDestinations())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.grafana.model.NotificationDestinationType.wrap(item)
          }.toList
        )
    override val workspaceOrganizationalUnits
        : Optional[List[OrganizationalUnit]] = zio.aws.core.internal
      .optionalFromNullable(impl.workspaceOrganizationalUnits())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.grafana.model.primitives.OrganizationalUnit(item)
        }.toList
      )
    override val workspaceRoleArn: Optional[IamRoleArn] = zio.aws.core.internal
      .optionalFromNullable(impl.workspaceRoleArn())
      .map(value => zio.aws.grafana.model.primitives.IamRoleArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.grafana.model.CreateWorkspaceRequest
  ): zio.aws.grafana.model.CreateWorkspaceRequest.ReadOnly = new Wrapper(impl)
}
